;; Generated package description from xah-fly-keys.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "xah-fly-keys" "28.11.20260712150256.0.20260712.0" "ergonomic modal keybinding minor mode." '((emacs "28.3")) :commit "158a4b12fce8e5f63694a68b75df89b064e73e14" :maintainer '("Xah Lee" . "xah@xahlee.org") :keywords '("convenience" "vi" "vim" "ergoemacs" "keybinding") :url "http://xahlee.info/emacs/misc/xah-fly-keys.html")
